==> herrie-0.1.tar.gz: herrie-0.1/src/gui/gui.h <==
/*
 * Copyright (c) 2006 Ed Schouten <ed@fxq.nl>
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 * $Id: gui.h 476 2006-08-01 06:26:05Z ed $
 */
/**
 * @file gui/gui.h
 */

#ifndef _GUI_GUI_H_
#define _GUI_GUI_H_

#include <pthread.h>

#include <audio/audio.h>
#include <vfs/vfs.h>

/**
 * @brief Initialize the curses GUI.
 */
void gui_draw_init(void);
/**
 * @brief Destroy the curses GUI.
 */
void gui_draw_destroy(void);
#ifdef HAVE_WRESIZE
/**
 * @brief Refresh the curses GUI after a terminal resize.
 */
void gui_draw_resize(void);
#endif /* HAVE_WRESIZE */

/**
 * @brief The mutex that locks the GUI down.
 */
extern pthread_mutex_t gui_lock;
/**
 * @brief Acquire a lock on the GUI.
 */
#define GUI_LOCK pthread_mutex_lock(&gui_lock)
/**
 * @brief Release a lock on the GUI.
 */
#define GUI_UNLOCK pthread_mutex_unlock(&gui_lock)

/* Display size ratios */
/**
 * @brief Height of playlist window.
 */
#define gui_size_playq_height		((LINES / 2) - 1)
/**
 * @brief Offset of the window containing the filebrowser's directory
 *        name.
 */
#define gui_size_browser_dirname_top	(gui_size_playq_height + 1)
/**
 * @brief Offset of the filebrowser window.
 */
#define gui_size_browser_top		(gui_size_browser_dirname_top + 1)
/**
 * @brief Height of the filebrowser window.
 */
#define gui_size_browser_height		(LINES - gui_size_browser_top)

/**
 * @brief Curses colour code used to draw bars (status, dirname).
 */
#define GUI_COLOR_BAR		2
/**
 * @brief Curses colour code used to draw blocks (playlist, browser).
 */
#define GUI_COLOR_BLOCK		3
/**
 * @brief Curses colour code used to draw focused selections.
 */
#define GUI_COLOR_SELECT	4
/**
 * @brief Curses colour code used to draw unfocused selections.
 */
#define GUI_COLOR_DESELECT	5

/**
 * @brief Read commands from the keyboard. Function terminates when user
 *        quits the application.
 */
void gui_inputloop(void);
/**
 * @brief Indicator of current selected window.
 */
extern int gui_input_curfocus;
/**
 * @brief The focus is on the browser.
 */
#define GUI_FOCUS_BROWSER	0
/**
 * @brief The focus is on the playlist.
 */
#define GUI_FOCUS_PLAYQ		1
/**
 * @brief The number of focusable windows.
 */
#define GUI_FOCUS_COUNT		2

/*
 * gui_statbar
 */
/**
 * @brief Create a bar at the top of the terminal displaying the
 *        name and time of the current song
 */
void gui_statbar_init(void);
/**
 * @brief Destroy the status bar at the top of the screen
 */
void gui_statbar_destroy(void);
/**
 * @brief Set the proper size of the status bar after a terminal resize
 */
void gui_statbar_resize(void);
/**
 * @brief Redraw the status bar after its contents have been altered
 */
void gui_statbar_refresh(void);
/**
 * @brief Set the name of the song and time showed in the status bar
 */
void gui_statbar_update(struct audio_file *fd);

/*
 * gui_playq
 */
/**
 * @brief Initialize the playlist window.
 */
void gui_playq_init(void);
/**
 * @brief Destroy the playlist window.
 */
void gui_playq_destroy(void);
/**
 * @brief Redraw the playlist window, because of a terminal resize.
 */
void gui_playq_resize(void);
/**
 * @brief Redraw the playlist window.
 */
void gui_playq_refresh(void);

/**
 * @brief Adjust the cursor and the viewport offset of the playlist
 *        right before the removal of the actual entry.
 */
void gui_playq_notify_pre_removal(int index);
/**
 * @brief Adjust the cursor and the viewport offset of the playlist
 *        right after the insertion of the actual entry.
 */
void gui_playq_notify_post_insertion(int index);
/**
 * @brief Adjust the cursor and the viewport offset of the playlist
 *        right after the randomization of the playlist.
 */
void gui_playq_notify_post_randomization(void);
/**
 * @brief Redraw the playlist, as the manipulation of the playlist is
 *        finished.
 */
void gui_playq_notify_done(void);

/**
 * @brief Move the cursor of the playlist one item up.
 */
void gui_playq_cursor_up(void);
/**
 * @brief Move the cursor of the playlist one item down.
 */
void gui_playq_cursor_down(void);
/**
 * @brief Move the cursor and the viewport of the playlist one page up.
 */
void gui_playq_cursor_pageup(void);
/**
 * @brief Move the cursor and the viewport of the playlist one page down.
 */
void gui_playq_cursor_pagedown(void);
/**
 * @brief Move the cursor and the viewport of the playlist to the top of
 *        the playlist.
 */
void gui_playq_cursor_top(void);
/**
 * @brief Move the cursor and the viewport of the playlist to the bottom
 *        of the playlist.
 */
void gui_playq_cursor_bottom(void);
/**
 * @brief Remove the currently selected song from the playlist.
 */
void gui_playq_song_remove(void);

/**
 * @brief Add a song before the selected item in the playlist.
 */
void gui_playq_song_add_before(struct vfs_ent *ve);
/**
 * @brief Add a song after the selected item in the playlist.
 */
void gui_playq_song_add_after(struct vfs_ent *ve);

/*
 * gui_browser
 */
/**
 * @brief Initialize the filebrowser window.
 */
void gui_browser_init(void);
/**
 * @brief Destroy the filebrowser window.
 */
void gui_browser_destroy(void);
/**
 * @brief Redraw the filebrowser, because of a terminal resize.
 */
void gui_browser_resize(void);
/**
 * @brief Refresh the filebrowser.
 */
void gui_browser_refresh(void);

/**
 * @brief Move the cursor of the filebrowser one position up.
 */
void gui_browser_cursor_up(void);
/**
 * @brief Move the cursor of the filebrowser one position down.
 */
void gui_browser_cursor_down(void);
/**
 * @brief Move the cursor and the viewport of the filebrowser one page
 *        up.
 */
void gui_browser_cursor_pageup(void);
/**
 * @brief Move the cursor and the viewport of the filebrowser one page
 *        down.
 */
void gui_browser_cursor_pagedown(void);
/**
 * @brief Move the cursor and the viewport of the filebrowser to the top
 *        of the current directory.
 */
void gui_browser_cursor_top(void);
/**
 * @brief Move the cursor and the viewport of the filebrowser to the
 *        bottom of the current directory.
 */
void gui_browser_cursor_bottom(void);
/**
 * @brief Change the current working directory of the filebrowser to the
 *        parent directory.
 */
void gui_browser_dir_parent(void);
/**
 * @brief Change the current working directory of the filebrowser to the
 *        currently selected item.
 */
void gui_browser_dir_enter(void);
/**
 * @brief Add the current selection to the tail of the playlist.
 */
void gui_browser_playq_add_tail(void);
/**
 * @brief Add the current selection to the head of the playlist.
 */
void gui_browser_playq_add_head(void);
/**
 * @brief Add the current selection after the selected item in the
 *        playlist.
 */
void gui_browser_playq_add_after(void);
/**
 * @brief Add the current selection before the selected item in the
 *        playlist.
 */
void gui_browser_playq_add_before(void);

#endif /* !_GUI_GUI_H_ */

==> herrie-0.6.tar.gz: herrie-0.6/src/gui/gui.h <==
/*
 * Copyright (c) 2006 Ed Schouten <ed@fxq.nl>
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 * $Id$
 */
/**
 * @file gui/gui.h
 */

#ifndef _GUI_GUI_H_
#define _GUI_GUI_H_

#include <glib.h>

#include <audio/audio.h>

/**
 * @brief Initialize the curses GUI.
 */
void gui_draw_init_pre(void);
/**
 * @brief Initialize trailing GUI components that can only be
 *        initialized after initializing locks and chroot()'ing.
 */
void gui_draw_init_post(void);
/**
 * @brief Destroy the curses GUI.
 */
void gui_draw_destroy(void);

/**
 * @brief Read commands from the keyboard. Function terminates when user
 *        quits the application.
 */
void gui_input_loop(void);

/**
 * @brief Update the text in the message bar.
 */
void gui_msgbar_update(const char *msg, int prio);

/**
 * @brief Set the name of the song and time showed in the status bar
 */
void gui_statbar_update(struct audio_file *fd, int timeonly);

/**
 * @brief Adjust the cursor and the viewport offset of the playlist
 *        right before the removal of the actual entry.
 */
void gui_playq_notify_pre_removal(unsigned int index);
/**
 * @brief Adjust the cursor and the viewport offset of the playlist
 *        right after the insertion of the actual entry.
 */
void gui_playq_notify_post_insertion(unsigned int index);
/**
 * @brief Adjust the cursor and the viewport offset of the playlist
 *        right after the randomization of the playlist.
 */
void gui_playq_notify_post_randomization(void);
/**
 * @brief Redraw the playlist, as the manipulation of the playlist is
 *        finished.
 */
void gui_playq_notify_done(void);

#endif /* !_GUI_GUI_H_ */
